# coding: utf-8

"""
    Antenny API

    This is an api that allows you to interact with the Antenny platform. It allows you to manage your clients and subscriptions.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: admin@antenny.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import antenny
from antenny.api.subscription_api import SubscriptionApi  # noqa: E501
from antenny.rest import ApiException


class TestSubscriptionApi(unittest.TestCase):
    """SubscriptionApi unit test stubs"""

    def setUp(self):
        self.api = antenny.api.subscription_api.SubscriptionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_subscription(self):
        """Test case for cancel_subscription

        Cancels a subscription  # noqa: E501
        """
        pass

    def test_create_subscription(self):
        """Test case for create_subscription

        Creates a subscription  # noqa: E501
        """
        pass

    def test_get_subscription(self):
        """Test case for get_subscription

        Gets a subscription  # noqa: E501
        """
        pass

    def test_list_subscriptions(self):
        """Test case for list_subscriptions

        Gets a list of subscriptions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Antenny API

    This is an api that allows you to interact with the Antenny platform. It allows you to manage your clients and subscriptions.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: admin@antenny.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import antenny
from antenny.models.inline_object import InlineObject  # noqa: E501
from antenny.rest import ApiException

class TestInlineObject(unittest.TestCase):
    """InlineObject unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InlineObject
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = antenny.models.inline_object.InlineObject()  # noqa: E501
        if include_optional :
            return InlineObject(
                status = 'CANCELED'
            )
        else :
            return InlineObject(
                status = 'CANCELED',
        )

    def testInlineObject(self):
        """Test InlineObject"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from antenny.api.client_api import ClientApi
from antenny.api.events_api import EventsApi
from antenny.api.registration_api import RegistrationApi
from antenny.api.subscription_api import SubscriptionApi



# coding: utf-8

"""
    Antenny API

    This is an api that allows you to interact with the Antenny platform. It allows you to manage your clients and subscriptions.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: admin@antenny.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from antenny.configuration import Configuration


class NewSubscription(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'customer_id': 'str',
        'region': 'str',
        'resource': 'Resource',
        'endpoint': 'Endpoint'
    }

    attribute_map = {
        'name': 'name',
        'customer_id': 'customerId',
        'region': 'region',
        'resource': 'resource',
        'endpoint': 'endpoint'
    }

    def __init__(self, name=None, customer_id=None, region=None, resource=None, endpoint=None, local_vars_configuration=None):  # noqa: E501
        """NewSubscription - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._customer_id = None
        self._region = None
        self._resource = None
        self._endpoint = None
        self.discriminator = None

        if name is not None:
            self.name = name
        self.customer_id = customer_id
        self.region = region
        self.resource = resource
        self.endpoint = endpoint

    @property
    def name(self):
        """Gets the name of this NewSubscription.  # noqa: E501


        :return: The name of this NewSubscription.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this NewSubscription.


        :param name: The name of this NewSubscription.  # noqa: E501
        :type name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 32):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `32`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 3):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `3`")  # noqa: E501

        self._name = name

    @property
    def customer_id(self):
        """Gets the customer_id of this NewSubscription.  # noqa: E501


        :return: The customer_id of this NewSubscription.  # noqa: E501
        :rtype: str
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this NewSubscription.


        :param customer_id: The customer_id of this NewSubscription.  # noqa: E501
        :type customer_id: str
        """
        if self.local_vars_configuration.client_side_validation and customer_id is None:  # noqa: E501
            raise ValueError("Invalid value for `customer_id`, must not be `None`")  # noqa: E501

        self._customer_id = customer_id

    @property
    def region(self):
        """Gets the region of this NewSubscription.  # noqa: E501


        :return: The region of this NewSubscription.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this NewSubscription.


        :param region: The region of this NewSubscription.  # noqa: E501
        :type region: str
        """
        if self.local_vars_configuration.client_side_validation and region is None:  # noqa: E501
            raise ValueError("Invalid value for `region`, must not be `None`")  # noqa: E501
        allowed_values = ["us-east-1", "us-east-2", "us-west-1", "us-west-2", "ap-northeast-1", "ap-northeast-2", "ap-southeast-1", "ap-southeast-2", "eu-central-1", "eu-west-1", "eu-west-2"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and region not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `region` ({0}), must be one of {1}"  # noqa: E501
                .format(region, allowed_values)
            )

        self._region = region

    @property
    def resource(self):
        """Gets the resource of this NewSubscription.  # noqa: E501


        :return: The resource of this NewSubscription.  # noqa: E501
        :rtype: Resource
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """Sets the resource of this NewSubscription.


        :param resource: The resource of this NewSubscription.  # noqa: E501
        :type resource: Resource
        """
        if self.local_vars_configuration.client_side_validation and resource is None:  # noqa: E501
            raise ValueError("Invalid value for `resource`, must not be `None`")  # noqa: E501

        self._resource = resource

    @property
    def endpoint(self):
        """Gets the endpoint of this NewSubscription.  # noqa: E501


        :return: The endpoint of this NewSubscription.  # noqa: E501
        :rtype: Endpoint
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this NewSubscription.


        :param endpoint: The endpoint of this NewSubscription.  # noqa: E501
        :type endpoint: Endpoint
        """
        if self.local_vars_configuration.client_side_validation and endpoint is None:  # noqa: E501
            raise ValueError("Invalid value for `endpoint`, must not be `None`")  # noqa: E501

        self._endpoint = endpoint

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NewSubscription):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NewSubscription):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Antenny API

    This is an api that allows you to interact with the Antenny platform. It allows you to manage your clients and subscriptions.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: admin@antenny.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from antenny.api_client import ApiClient
from antenny.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class EventsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def list_events(self, sub_id, **kwargs):  # noqa: E501
        """Gets a list of events for a subscription  # noqa: E501

        Lists events for a subscription  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_events(sub_id, async_req=True)
        >>> result = thread.get()

        :param sub_id: Subscription id (required)
        :type sub_id: str
        :param sort: Defines sort direction
        :type sort: str
        :param level: Filters events by level
        :type level: str
        :param limit: Limits the number of returned items
        :type limit: int
        :param start_key: Defines start of page of results
        :type start_key: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: EventList
        """
        kwargs['_return_http_data_only'] = True
        return self.list_events_with_http_info(sub_id, **kwargs)  # noqa: E501

    def list_events_with_http_info(self, sub_id, **kwargs):  # noqa: E501
        """Gets a list of events for a subscription  # noqa: E501

        Lists events for a subscription  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_events_with_http_info(sub_id, async_req=True)
        >>> result = thread.get()

        :param sub_id: Subscription id (required)
        :type sub_id: str
        :param sort: Defines sort direction
        :type sort: str
        :param level: Filters events by level
        :type level: str
        :param limit: Limits the number of returned items
        :type limit: int
        :param start_key: Defines start of page of results
        :type start_key: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(EventList, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'sub_id',
            'sort',
            'level',
            'limit',
            'start_key'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_events" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'sub_id' is set
        if self.api_client.client_side_validation and ('sub_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['sub_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `sub_id` when calling `list_events`")  # noqa: E501

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 50:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `list_events`, must be a value less than or equal to `50`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `list_events`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'sub_id' in local_var_params:
            path_params['subId'] = local_var_params['sub_id']  # noqa: E501

        query_params = []
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'level' in local_var_params and local_var_params['level'] is not None:  # noqa: E501
            query_params.append(('level', local_var_params['level']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'start_key' in local_var_params and local_var_params['start_key'] is not None:  # noqa: E501
            query_params.append(('startKey', local_var_params['start_key']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subId}/events', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EventList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

# flake8: noqa
"""
    Antenny API

    This is an api that allows you to interact with the Antenny platform. It allows you to manage your clients and subscriptions.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: admin@antenny.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from antenny.models.client import Client
from antenny.models.client_list import ClientList
from antenny.models.endpoint import Endpoint
from antenny.models.event import Event
from antenny.models.event_list import EventList
from antenny.models.inline_object import InlineObject
from antenny.models.new_client import NewClient
from antenny.models.new_subscription import NewSubscription
from antenny.models.registration import Registration
from antenny.models.resource import Resource
from antenny.models.subscription import Subscription
from antenny.models.subscription_list import SubscriptionList



# coding: utf-8

"""
    Antenny API

    This is an api that allows you to interact with the Antenny platform. It allows you to manage your clients and subscriptions.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: admin@antenny.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from antenny.configuration import Configuration


class EventList(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'items': 'list[Event]',
        'last_key': 'str'
    }

    attribute_map = {
        'items': 'items',
        'last_key': 'lastKey'
    }

    def __init__(self, items=None, last_key=None, local_vars_configuration=None):  # noqa: E501
        """EventList - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._items = None
        self._last_key = None
        self.discriminator = None

        if items is not None:
            self.items = items
        self.last_key = last_key

    @property
    def items(self):
        """Gets the items of this EventList.  # noqa: E501


        :return: The items of this EventList.  # noqa: E501
        :rtype: list[Event]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this EventList.


        :param items: The items of this EventList.  # noqa: E501
        :type items: list[Event]
        """

        self._items = items

    @property
    def last_key(self):
        """Gets the last_key of this EventList.  # noqa: E501


        :return: The last_key of this EventList.  # noqa: E501
        :rtype: str
        """
        return self._last_key

    @last_key.setter
    def last_key(self, last_key):
        """Sets the last_key of this EventList.


        :param last_key: The last_key of this EventList.  # noqa: E501
        :type last_key: str
        """

        self._last_key = last_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventList):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EventList):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Antenny API

    This is an api that allows you to interact with the Antenny platform. It allows you to manage your clients and subscriptions.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: admin@antenny.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from antenny.api.client_api import ClientApi
from antenny.api.events_api import EventsApi
from antenny.api.registration_api import RegistrationApi
from antenny.api.subscription_api import SubscriptionApi

# import ApiClient
from antenny.api_client import ApiClient
from antenny.configuration import Configuration
from antenny.exceptions import OpenApiException
from antenny.exceptions import ApiTypeError
from antenny.exceptions import ApiValueError
from antenny.exceptions import ApiKeyError
from antenny.exceptions import ApiAttributeError
from antenny.exceptions import ApiException
# import models into sdk package
from antenny.models.client import Client
from antenny.models.client_list import ClientList
from antenny.models.endpoint import Endpoint
from antenny.models.event import Event
from antenny.models.event_list import EventList
from antenny.models.inline_object import InlineObject
from antenny.models.new_client import NewClient
from antenny.models.new_subscription import NewSubscription
from antenny.models.registration import Registration
from antenny.models.resource import Resource
from antenny.models.subscription import Subscription
from antenny.models.subscription_list import SubscriptionList




# coding: utf-8

"""
    Antenny API

    This is an api that allows you to interact with the Antenny platform. It allows you to manage your clients and subscriptions.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: admin@antenny.io
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "antenny-py"
VERSION = "1.0.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Antenny API",
    author="OpenAPI Generator community",
    author_email="admin@antenny.io",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Antenny API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Apache 2.0",
    long_description="""\
    This is an api that allows you to interact with the Antenny platform. It allows you to manage your clients and subscriptions.  # noqa: E501
    """
)



# coding: utf-8

"""
    Antenny API

    This is an api that allows you to interact with the Antenny platform. It allows you to manage your clients and subscriptions.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: admin@antenny.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from antenny.configuration import Configuration


class Event(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'subscription_id': 'str',
        'customer_id': 'str',
        'level': 'str',
        'message': 'str',
        'created': 'date',
        'modified': 'date'
    }

    attribute_map = {
        'id': 'id',
        'subscription_id': 'subscriptionId',
        'customer_id': 'customerId',
        'level': 'level',
        'message': 'message',
        'created': 'created',
        'modified': 'modified'
    }

    def __init__(self, id=None, subscription_id=None, customer_id=None, level=None, message=None, created=None, modified=None, local_vars_configuration=None):  # noqa: E501
        """Event - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._subscription_id = None
        self._customer_id = None
        self._level = None
        self._message = None
        self._created = None
        self._modified = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if subscription_id is not None:
            self.subscription_id = subscription_id
        if customer_id is not None:
            self.customer_id = customer_id
        if level is not None:
            self.level = level
        if message is not None:
            self.message = message
        if created is not None:
            self.created = created
        if modified is not None:
            self.modified = modified

    @property
    def id(self):
        """Gets the id of this Event.  # noqa: E501


        :return: The id of this Event.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Event.


        :param id: The id of this Event.  # noqa: E501
        :type id: str
        """

        self._id = id

    @property
    def subscription_id(self):
        """Gets the subscription_id of this Event.  # noqa: E501


        :return: The subscription_id of this Event.  # noqa: E501
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """Sets the subscription_id of this Event.


        :param subscription_id: The subscription_id of this Event.  # noqa: E501
        :type subscription_id: str
        """

        self._subscription_id = subscription_id

    @property
    def customer_id(self):
        """Gets the customer_id of this Event.  # noqa: E501


        :return: The customer_id of this Event.  # noqa: E501
        :rtype: str
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this Event.


        :param customer_id: The customer_id of this Event.  # noqa: E501
        :type customer_id: str
        """

        self._customer_id = customer_id

    @property
    def level(self):
        """Gets the level of this Event.  # noqa: E501


        :return: The level of this Event.  # noqa: E501
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """Sets the level of this Event.


        :param level: The level of this Event.  # noqa: E501
        :type level: str
        """
        allowed_values = ["INFO", "WARNING", "ERROR"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and level not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `level` ({0}), must be one of {1}"  # noqa: E501
                .format(level, allowed_values)
            )

        self._level = level

    @property
    def message(self):
        """Gets the message of this Event.  # noqa: E501


        :return: The message of this Event.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this Event.


        :param message: The message of this Event.  # noqa: E501
        :type message: str
        """

        self._message = message

    @property
    def created(self):
        """Gets the created of this Event.  # noqa: E501


        :return: The created of this Event.  # noqa: E501
        :rtype: date
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Event.


        :param created: The created of this Event.  # noqa: E501
        :type created: date
        """

        self._created = created

    @property
    def modified(self):
        """Gets the modified of this Event.  # noqa: E501


        :return: The modified of this Event.  # noqa: E501
        :rtype: date
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this Event.


        :param modified: The modified of this Event.  # noqa: E501
        :type modified: date
        """

        self._modified = modified

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Event):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Event):
            return True

        return self.to_dict() != other.to_dict()
